{% extends 'base.html' %}

{% block content %}

<div class="hero-unit" >

    <h3> Login with Tribe: </h3>
    <a href="{{ tribe_url }}/oauth2/authorize/?response_type=code&client_id={{client_id}}&scope={{scope}}">Tribe Login Page</a>

</div>

{% endblock %}

